# The Prelude

Use this library to run continuous security tests on all your endpoints.

It works like this:

1. Deploy agents around your network
2. Upload TTPs to your Outpost server
3. Activate the TTPs you want running continuously

This library supplies access to the Prelude API. You must have a valid account to use it. Create a 
~/.prelude/keychain.ini file with your account info, such as:

```
[default]
hq = http://localhost:8080
account = a60ba00b4e1254cd5221cb77527190c6
token = 65277d48-71d0-4f39-ad05-c581a51d7f82
key = af3c199c2470cb477d907b1e0917c17a
```

## Usage guide

A basic use case for continuous security testing:

> Please review docstrings to see optional parameters and functions not shown here.

```python
from theprelude import detect

# Add an Outpost database to hold custom TTPs. 
# Upload TTPs and activate the ones I want running now.
# Register an endpoint and it'll get to work.

account = detect.Account(hq='http://localhost:8080')
account.add_oupost(address='http://localhost:9753', token='abc123')
account.upload('/tmp/43b3754c-def4-4699-a673-1d85648fda6a.yml')
account.upload('/tmp/b5f13f87-ee76-463e-8906-dbe966500a8.json')
account.activate('43b3754c-def4-4699-a673-1d85648fda6a', detect.RunCode.CONTINUOUS)
account.activate('b5f13f87-ee76-463e-8906-dbe966500a8', detect.RunCode.ONCE)
token = account.register('host/1')
print('Start a mini agent anywhere with this token: %s' % token)

# Done testing? Deactivate the TTPs I don't want running.
# Check my results then search for some more TTPs to activate.

account.deactivate('43b3754c-def4-4699-a673-1d85648fda6a') 
last_7_days = account.results(days=7)
all_my_ttps = account.search()
```

## Developer guide

Make changes then install locally before testing:
```
pip install .
```

To publish a new version on [PyPy](https://pypi.org/project/theprelude/):
```commandline
python -m build
python -m twine upload --repository pypi dist/*
```
